@@ -95,6 +95,8 @@ class EmailMessage(object):
         msg['To'] = ', '.join(self.to)
         if self.cc:
             msg['Cc'] = ', '.join(self.cc)
+        if self.bcc:
+            msg['Bcc'] = ', '.join(self.bcc)
 
         # Email header names are case-insensitive (RFC 2045), so we have to
         # accommodate that when doing comparisons.
